# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_rpm
from pulpcore.client.pulp_rpm.models.rpm_rpm_publication_response import RpmRpmPublicationResponse  # noqa: E501
from pulpcore.client.pulp_rpm.rest import ApiException

class TestRpmRpmPublicationResponse(unittest.TestCase):
    """RpmRpmPublicationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RpmRpmPublicationResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_rpm.models.rpm_rpm_publication_response.RpmRpmPublicationResponse()  # noqa: E501
        if include_optional :
            return RpmRpmPublicationResponse(
                pulp_href = '0', 
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                repository_version = '0', 
                repository = '0', 
                checksum_type = null, 
                metadata_checksum_type = null, 
                package_checksum_type = null, 
                gpgcheck = 0, 
                repo_gpgcheck = 0, 
                sqlite_metadata = True, 
                repo_config = pulpcore.client.pulp_rpm.models.repo_config.repo_config(), 
                compression_type = null
            )
        else :
            return RpmRpmPublicationResponse(
        )

    def testRpmRpmPublicationResponse(self):
        """Test RpmRpmPublicationResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class RepositoryVersionResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'number': 'int',
        'repository': 'str',
        'base_version': 'str',
        'content_summary': 'ContentSummaryResponse'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'number': 'number',
        'repository': 'repository',
        'base_version': 'base_version',
        'content_summary': 'content_summary'
    }

    def __init__(self, pulp_href=None, pulp_created=None, number=None, repository=None, base_version=None, content_summary=None, local_vars_configuration=None):  # noqa: E501
        """RepositoryVersionResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._number = None
        self._repository = None
        self._base_version = None
        self._content_summary = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        if number is not None:
            self.number = number
        if repository is not None:
            self.repository = repository
        if base_version is not None:
            self.base_version = base_version
        if content_summary is not None:
            self.content_summary = content_summary

    @property
    def pulp_href(self):
        """Gets the pulp_href of this RepositoryVersionResponse.  # noqa: E501


        :return: The pulp_href of this RepositoryVersionResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this RepositoryVersionResponse.


        :param pulp_href: The pulp_href of this RepositoryVersionResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this RepositoryVersionResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this RepositoryVersionResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this RepositoryVersionResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this RepositoryVersionResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def number(self):
        """Gets the number of this RepositoryVersionResponse.  # noqa: E501


        :return: The number of this RepositoryVersionResponse.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this RepositoryVersionResponse.


        :param number: The number of this RepositoryVersionResponse.  # noqa: E501
        :type: int
        """

        self._number = number

    @property
    def repository(self):
        """Gets the repository of this RepositoryVersionResponse.  # noqa: E501


        :return: The repository of this RepositoryVersionResponse.  # noqa: E501
        :rtype: str
        """
        return self._repository

    @repository.setter
    def repository(self, repository):
        """Sets the repository of this RepositoryVersionResponse.


        :param repository: The repository of this RepositoryVersionResponse.  # noqa: E501
        :type: str
        """

        self._repository = repository

    @property
    def base_version(self):
        """Gets the base_version of this RepositoryVersionResponse.  # noqa: E501

        A repository version whose content was used as the initial set of content for this repository version  # noqa: E501

        :return: The base_version of this RepositoryVersionResponse.  # noqa: E501
        :rtype: str
        """
        return self._base_version

    @base_version.setter
    def base_version(self, base_version):
        """Sets the base_version of this RepositoryVersionResponse.

        A repository version whose content was used as the initial set of content for this repository version  # noqa: E501

        :param base_version: The base_version of this RepositoryVersionResponse.  # noqa: E501
        :type: str
        """

        self._base_version = base_version

    @property
    def content_summary(self):
        """Gets the content_summary of this RepositoryVersionResponse.  # noqa: E501

        Various count summaries of the content in the version and the HREF to view them.  # noqa: E501

        :return: The content_summary of this RepositoryVersionResponse.  # noqa: E501
        :rtype: ContentSummaryResponse
        """
        return self._content_summary

    @content_summary.setter
    def content_summary(self, content_summary):
        """Sets the content_summary of this RepositoryVersionResponse.

        Various count summaries of the content in the version and the HREF to view them.  # noqa: E501

        :param content_summary: The content_summary of this RepositoryVersionResponse.  # noqa: E501
        :type: ContentSummaryResponse
        """

        self._content_summary = content_summary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RepositoryVersionResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RepositoryVersionResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class RpmRepositorySyncURL(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'remote': 'str',
        'mirror': 'bool',
        'sync_policy': 'SyncPolicyEnum',
        'skip_types': 'list[SkipTypesEnum]',
        'optimize': 'bool'
    }

    attribute_map = {
        'remote': 'remote',
        'mirror': 'mirror',
        'sync_policy': 'sync_policy',
        'skip_types': 'skip_types',
        'optimize': 'optimize'
    }

    def __init__(self, remote=None, mirror=None, sync_policy=None, skip_types=[], optimize=True, local_vars_configuration=None):  # noqa: E501
        """RpmRepositorySyncURL - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._remote = None
        self._mirror = None
        self._sync_policy = None
        self._skip_types = None
        self._optimize = None
        self.discriminator = None

        if remote is not None:
            self.remote = remote
        self.mirror = mirror
        self.sync_policy = sync_policy
        if skip_types is not None:
            self.skip_types = skip_types
        if optimize is not None:
            self.optimize = optimize

    @property
    def remote(self):
        """Gets the remote of this RpmRepositorySyncURL.  # noqa: E501

        A remote to sync from. This will override a remote set on repository.  # noqa: E501

        :return: The remote of this RpmRepositorySyncURL.  # noqa: E501
        :rtype: str
        """
        return self._remote

    @remote.setter
    def remote(self, remote):
        """Sets the remote of this RpmRepositorySyncURL.

        A remote to sync from. This will override a remote set on repository.  # noqa: E501

        :param remote: The remote of this RpmRepositorySyncURL.  # noqa: E501
        :type: str
        """

        self._remote = remote

    @property
    def mirror(self):
        """Gets the mirror of this RpmRepositorySyncURL.  # noqa: E501

        DEPRECATED: If ``True``, ``sync_policy`` will default to 'mirror_complete' instead of 'additive'.  # noqa: E501

        :return: The mirror of this RpmRepositorySyncURL.  # noqa: E501
        :rtype: bool
        """
        return self._mirror

    @mirror.setter
    def mirror(self, mirror):
        """Sets the mirror of this RpmRepositorySyncURL.

        DEPRECATED: If ``True``, ``sync_policy`` will default to 'mirror_complete' instead of 'additive'.  # noqa: E501

        :param mirror: The mirror of this RpmRepositorySyncURL.  # noqa: E501
        :type: bool
        """

        self._mirror = mirror

    @property
    def sync_policy(self):
        """Gets the sync_policy of this RpmRepositorySyncURL.  # noqa: E501

        Options: 'additive', 'mirror_complete', 'mirror_content_only'. Default: 'additive'. Modifies how the sync is performed. 'mirror_complete' will clone the original metadata and create an automatic publication from it, but comes with some limitations and does not work for certain repositories. 'mirror_content_only' will change the repository contents to match the remote but the metadata will be regenerated and will not be bit-for-bit identical. 'additive' will retain the existing contents of the repository and add the contents of the repository being synced.  * `additive` - additive * `mirror_complete` - mirror_complete * `mirror_content_only` - mirror_content_only  # noqa: E501

        :return: The sync_policy of this RpmRepositorySyncURL.  # noqa: E501
        :rtype: SyncPolicyEnum
        """
        return self._sync_policy

    @sync_policy.setter
    def sync_policy(self, sync_policy):
        """Sets the sync_policy of this RpmRepositorySyncURL.

        Options: 'additive', 'mirror_complete', 'mirror_content_only'. Default: 'additive'. Modifies how the sync is performed. 'mirror_complete' will clone the original metadata and create an automatic publication from it, but comes with some limitations and does not work for certain repositories. 'mirror_content_only' will change the repository contents to match the remote but the metadata will be regenerated and will not be bit-for-bit identical. 'additive' will retain the existing contents of the repository and add the contents of the repository being synced.  * `additive` - additive * `mirror_complete` - mirror_complete * `mirror_content_only` - mirror_content_only  # noqa: E501

        :param sync_policy: The sync_policy of this RpmRepositorySyncURL.  # noqa: E501
        :type: SyncPolicyEnum
        """

        self._sync_policy = sync_policy

    @property
    def skip_types(self):
        """Gets the skip_types of this RpmRepositorySyncURL.  # noqa: E501

        List of content types to skip during sync.  # noqa: E501

        :return: The skip_types of this RpmRepositorySyncURL.  # noqa: E501
        :rtype: list[SkipTypesEnum]
        """
        return self._skip_types

    @skip_types.setter
    def skip_types(self, skip_types):
        """Sets the skip_types of this RpmRepositorySyncURL.

        List of content types to skip during sync.  # noqa: E501

        :param skip_types: The skip_types of this RpmRepositorySyncURL.  # noqa: E501
        :type: list[SkipTypesEnum]
        """

        self._skip_types = skip_types

    @property
    def optimize(self):
        """Gets the optimize of this RpmRepositorySyncURL.  # noqa: E501

        Whether or not to optimize sync.  # noqa: E501

        :return: The optimize of this RpmRepositorySyncURL.  # noqa: E501
        :rtype: bool
        """
        return self._optimize

    @optimize.setter
    def optimize(self, optimize):
        """Sets the optimize of this RpmRepositorySyncURL.

        Whether or not to optimize sync.  # noqa: E501

        :param optimize: The optimize of this RpmRepositorySyncURL.  # noqa: E501
        :type: bool
        """

        self._optimize = optimize

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RpmRepositorySyncURL):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RpmRepositorySyncURL):
            return True

        return self.to_dict() != other.to_dict()
